SqfliteDarwin class

sqflite_darwin plugin

Inheritance
  • Object
  • PlatformInterface
  • SqflitePlatform
  • SqfliteDarwin

Constructors

SqfliteDarwin()

Properties

databaseFactory ↔ DatabaseFactory
Get the database factory
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void
Main entry point called by the Flutter platform.